---
name: "Bug report \U0001F41B"
about: "If something isn't working as expected \U0001F914."
title: ""
labels: bug
---

**Describe the bug**
A clear and concise description of what the bug is.
_What happened? And what did you expect to happen?_

**To Reproduce**
Steps to reproduce the problem:

**Screenshots**
If applicable, add screenshots to help explain your problem.

**Version information**

- OS: [e.g. Windows]
- Browser (if applicable) [e.g. Chrome]
- ASReview version [e.g. 0.6.2]

**Additional context**
Add any other context about the problem here.
